<?php

// Widget class
class Ena_Widget_Category_Preview extends WP_Widget {

/*-----------------------------------------------------------------------------------*/
/*  Widget Setup
/*-----------------------------------------------------------------------------------*/

 public function __construct() {
    parent::__construct(
      'category_preview', // Base ID
      __( 'Ena - Post List', 'enamag' ), // Widget Name
      array(
        'classname' => 'widget-category-preview',
        'description' => __( 'Post list.', 'enamag' ),
      ),
      array(
        'width' => 250,
      )
    );

  }
/*-----------------------------------------------------------------------------------*/
/*  Display Widget
/*-----------------------------------------------------------------------------------*/

  /**
   * Widget output.
   *
   * @since  1.0
   *
   * @access public
   * @param  array $args
   * @param  array $inst
   */
  public function widget( $args, $inst ) {
    extract( $args );
     // Background Title Color
    $color = isset( $inst['background_color'] ) ? esc_attr( $inst['background_color'] ) : '#FFA500 ';
    $title = isset( $inst['title'] ) ? esc_attr( $inst['title'] ) : '';
    $title = apply_filters( 'widget_title', $title, $inst, $this->id_base );
    $offset = $excerpt = $cats_id = $nbr_posts = $primary_post = $sec_posts =  NULL;
  
    if (! empty( $inst['excerpt'] ) ) { $excerpt = esc_attr( $inst['excerpt'] ); }
    if (! empty( $inst['cats_id'] ) ) { $cats_id = esc_attr( $inst['cats_id'] ); }
    if (! empty( $inst['offset'] )) { $offset = esc_attr( $inst['offset'] ); }
    if (! empty( $inst['primaryPost'] )) { $primary_post = esc_attr( $inst['primaryPost'] ); }
    if (! empty( $inst['sec_posts'] )) { $sec_posts = esc_attr( $inst['sec_posts'] ); }
    if (! empty( $inst['nbr_posts'] )) { $nbr_posts = esc_attr( $inst['nbr_posts'] ); }



    echo $before_widget; 

    $mar_query = new WP_Query(
      array(
        'posts_per_page' => 1,
        'cat' => $cats_id ,
        'ignore_sticky_posts' => 1,
        'offset'=>$offset,
        )
      ); 
        ?>

      <h4 class="widgetTitle" style="background:<?php echo $color ; ?>!important">

    <?php if ( $title && !empty( $title ) ){ ?>

      <?php echo '<span>'.$title.'</span>' ;

      }
       echo '</h4>'; 
    
    if ($mar_query->have_posts()): while ($mar_query->have_posts()) : $mar_query->the_post() ?>

      <div class="widgetBody" style="border-color:<?php echo $color.' transparent' ; ?>">

      <?php  if (isset($primary_post) AND $primary_post == '1') {?>

      <div class="primaryPost">
          <div class="excerpt-img">
              <a href='<?php the_permalink(); ?>' title='<?php the_title_attribute(); ?>' >
                    <?php the_post_thumbnail('enamag-widget'); ?>
              </a>
              <a href="<?php the_post_thumbnail_url(); ?>" class="prettyPhoto" title="<?php the_title_attribute(); ?>" >
                  <div class="tumbOptions magOpacity">
                  <span class='fa fa-arrows-alt'></span>
                  </div>
              </a>
          </div>
          <div class="post-contentPrimary">
              <h3 class="post-titlePrimary">
                  <a href='<?php the_permalink(); ?>' title='<?php the_title_attribute(); ?>' >
                  <?php the_title(); ?>
                  </a>
              </h3>
              <span class="box-meta">

                 <?php enamag_post_meta() ?>

              </span>

              <?php if ( $excerpt ): ?>

              <div class="excerpt">

                  <?php the_excerpt(); ?>

              </div>

              <?php endif; ?>

          </div>
      </div>          

      <?php 
      } 
      endwhile; 
      endif; 
    // rewind
    rewind_posts(); ?>

   
     <ul class="secondaryPost">
    <?php
      // secondary posts
    ( $primary_post == '1' ) ? $sec_post_off = $offset+1 : $sec_post_off = $offset ;
    $mar_query = new WP_Query(
      array(
       'posts_per_page' => $nbr_posts,
       'cat' => $cats_id,
       'offset'=>$sec_post_off
       )
    );

     if ( $sec_posts AND $sec_posts == '1' ) { 
         if ( $mar_query->have_posts() ):  while ( $mar_query->have_posts() ) : $mar_query->the_post() ?>    

     
        
      
       <li class="post-list-thumbnail">
                    <a class="thumb-lik" href='<?php the_permalink(); ?>' title='<?php the_title_attribute(); ?>' >
                        <?php the_post_thumbnail( 'thumbnail' ) ?>                    
                    </a>
                
                    <div class="content">
                        <a class="post-title" href='<?php the_permalink(); ?>' title='<?php the_title_attribute(); ?>' >
                        <?php the_title(); ?>
                        </a>
                        <span class="box-meta">
                         <?php enamag_post_meta() ?>
                        </span>
                     </div>
                </li>

      <?php  
        endwhile; 
        wp_reset_postdata(); 
        endif; 
        } 
      ?>
</ul>
      <div class="clear"></div>

      </div><!--widgetBody-->

      <?php 
            echo $after_widget;
  }

  /**
   * Saves widget settings.
   *
   * @since  1.0
   *
   * @access public
   * @param  array $new_instance
   * @param  array $old_instance
   * @return array
   */
  public function update( $new_instance,$old_instance ){
    $instance = $old_instance;
    $instance['title'] = strip_tags($new_instance['title']);
    $instance['cats_id'] = implode(',' , $new_instance['cats_id']  );
    $instance['nbr_posts'] = (int)$new_instance['nbr_posts'];
    $instance['offset'] = (int)$new_instance['offset'];
    $instance['sec_posts'] = (bool) $new_instance['sec_posts'];
    $instance['excerpt'] = (bool) $new_instance['excerpt'];
    $instance['background_color'] = $new_instance['background_color'];
    $instance['primaryPost'] = (bool) $new_instance['primaryPost'];

    return $instance;
  }
  /**
   * Prints the settings form.
   *
   * @since  1.0
   *
   * @access public
   * @param  array $inst
   */
  public function form( $inst ) {
    // Defaults
    $primary_post = isset( $inst['primaryPost'] ) ? (bool) $inst['primaryPost'] : true;
    $title = isset( $inst['title'] ) ? esc_attr( $inst['title'] ) : '';
    $nbr_posts = isset( $inst['nbr_posts'] ) ? esc_attr( $inst['nbr_posts'] ) : '4';
    $offset = isset( $inst['offset'] ) ? esc_attr( $inst['offset'] ) : '0';
    $sec_posts = isset( $inst['sec_posts'] ) ? (bool) esc_attr( $inst['sec_posts'] ) : '';
    $excerpt = isset( $inst['excerpt'] ) ? (bool) esc_attr( $inst['excerpt'] ) : ''; 
    $background_color = isset( $inst['background_color'] ) ? esc_attr( $inst['background_color'] ) : '#FFA500 ';
    $category = isset( $inst['cats_id'] ) ? esc_attr( $inst['cats_id'] ) : '';
    $cats_id = explode ( ',' , $category ) ;
    $categories_obj = get_categories();
    $categories = array();
    
    foreach ( $categories_obj as $pn_cat ) {
      $categories[$pn_cat->cat_ID] = $pn_cat->cat_name;
    }
    ?>

    <p>
      <label for="<?php echo $this->get_field_id( 'background_color' ); ?>"><?php _e( 'Border Color:', 'enamag' );?><br></label>
      <input class="color-picker" type="text" id="<?php echo $this->get_field_id( 'background_color' ); ?>" name="<?php echo $this->get_field_name( 'background_color' ); ?>" value="<?php echo  $background_color ; ?>" />                            
    </p>
    <p>
      <label for="<?php  echo $this->get_field_id( "title" ) ;?>"><?php _e( 'Title:', 'enamag' ); ?></label>
      <input class="widefat" value="<?php echo $title;?>" name="<?php  echo $this->get_field_name( "title" ) ;?>" type="text" id="<?php  echo $this->get_field_id("title") ;?>"/>
    </p>
    <p>
      <label for="<?php echo $this->get_field_id( 'cats_id' ); ?>"><?php _e( 'Select Category:', 'enamag' );?></label><br>
      <select class="widefat" multiple="multiple" id="<?php echo $this->get_field_id( 'cats_id' ); ?>[]" name="<?php echo $this->get_field_name( 'cats_id' ); ?>[]">
        <?php foreach ( $categories as $key => $option ) { ?>
        <option value="<?php echo $key ?>" <?php if ( in_array( $key , $cats_id ) ) { echo ' selected="selected"' ; } ?>><?php echo $option.' ( '.get_category_by_slug( $option )->count.' Post(s) )'; ?></option>
        <?php  } ?>
      </select>
    </p>
    <p>
      <label for="<?php  echo $this->get_field_id( "primaryPost" ) ;?>"><?php _e( 'Primary Post:', 'enamag' );?> </label>
      <input <?php checked( $primary_post ); ?>  type="checkbox"  name="<?php  echo $this->get_field_name( "primaryPost" ) ;?>" id="<?php  echo $this->get_field_id( "primaryPost" ) ;?>" />
    </p>
    <p>
      <label for="<?php  echo $this->get_field_id( "excerpt" ) ;?>"><?php _e( 'Show Excerpt:', 'enamag' );?> </label>
      <input <?php checked( $excerpt ); ?>  type="checkbox"  name="<?php  echo $this->get_field_name( "excerpt" ) ;?>" id="<?php  echo $this->get_field_id( "excerpt" ) ;?>" />
    </p>

    <p>
      <label for="<?php  echo $this->get_field_id( "sec_posts" ) ;?>"><?php _e( 'Secondary Posts:', 'enamag' );?> </label>
      <input <?php checked($sec_posts ); ?>  type="checkbox"  name="<?php  echo $this->get_field_name( "sec_posts" ) ;?>" id="<?php  echo $this->get_field_id( "sec_posts" ) ;?>" />
    </p>
     <p>
      <label for="<?php  echo $this->get_field_id( "offset" ) ;?>"><?php _e( 'Offset (Number of posts to pass over):', 'enamag' ); ?></label>
      <input  value="<?php echo $offset;?>" type="text" size="3" name="<?php  echo $this->get_field_name( "offset" ) ;?>" id="<?php  echo $this->get_field_id( "offset" ) ;?>" />
    </p>
    <p>
      <label for="<?php  echo $this->get_field_id( "nbr_posts" ) ;?>"><?php _e( 'Number of posts to show:', 'enamag' ); ?></label>
      <input  value="<?php echo $nbr_posts;?>" type="text" size="3" name="<?php  echo $this->get_field_name( "nbr_posts" ) ;?>" id="<?php  echo $this->get_field_id( "nbr_posts" ) ;?>" />
    </p>
    
    <?php
  }
}

add_action( 'widgets_init', 'ena_widget_category_preview' );
function ena_widget_category_preview() {
  register_widget( 'Ena_Widget_Category_Preview' );
}
