<?php

// Widget class
class Ena_Widget_Large extends WP_Widget{
/*-----------------------------------------------------------------------------------*/
/*  Widget Setup
/*-----------------------------------------------------------------------------------*/

  public function __construct() {
    parent::__construct(
      'large_widget', // Base ID
      __( 'Ena - Posts in Rows', 'enamag' ), // Widget Name
      array(
        'classname' => 'widget-large col-double',
        'description' => __( 'Posts in Rows.', 'enamag' ),
      ),
      array(
        'width' => 250,
      )
    );

  }
/*-----------------------------------------------------------------------------------*/
/*  Display Widget
/*-----------------------------------------------------------------------------------*/

  /**
   * Widget output.
   *
   * @since  1.0
   *
   * @access public
   * @param  array $args
   * @param  array $inst
   */
  public function widget($args,$inst){

    extract($args);
    // Background Title Color
    $color = isset( $inst['background_color'] ) ? esc_attr( $inst['background_color'] ) : '#FFA500';
    $title = isset( $inst['title'] ) ? esc_attr( $inst['title'] ) : '';
    $title = apply_filters( 'widget_title', $title, $inst, $this->id_base );
    $offset = $cats_id = $nbr_posts = null;
    if (! empty( $inst['offset'] ) ) { $offset = $inst['offset']; }
    if (! empty( $inst['nbr_posts'] ) ) { $nbr_posts = esc_attr( $inst['nbr_posts'] ); }
    if (! empty( $inst['cats_id'] ) ) { $cats_id = esc_attr( $inst['cats_id'] ); }

    echo $before_widget;
    ?>

     <h4 class="widgetTitle" style="background:<?php echo $color ; ?>!important">

        <?php if ( $title && !empty( $title ) ){ ?>

          <?php echo '<span>'.$title.'</span>' ;

          } ?>

          </h4>
          <div class="widgetBody" style="border-color:<?php echo $color.' transparent' ; ?>">        

      <?php 
      $cat_query = new WP_Query(
        array(
          'posts_per_page' => $nbr_posts,
          'cat' => $cats_id,
          'ignore_sticky_posts' => 1,
          'offset' => $offset,
          )
        ); 

        ?>

        <?php if ($cat_query->have_posts()): while ($cat_query->have_posts()) : $cat_query->the_post() ?>    

              <div class="primaryPost">
               <div class="excerpt-img">
                <a href='<?php the_permalink(); ?>' title='<?php the_title_attribute(); ?>' >
                <?php the_post_thumbnail('enamag-widget'); ?>
                </a>
                <a href="<?php the_post_thumbnail_url(); ?>" class="prettyPhoto" title="<?php the_title_attribute(); ?>" >
                  <div class="tumbOptions magOpacity">
                    <span class='fa fa-arrows-alt'></span>
                  </div>
                </a>
              </div>
                <div class="post-contentPrimary">

                  <?php
                  the_title( '<h3 class="post-titlePrimary"><a href="' . esc_url( get_permalink() ) . '">', '</a></h3>' );
                  ?>

                  <span class="box-meta">

                    <?php enamag_post_meta() ?>

                  </span>
                </div>

                <?php the_excerpt(); ?>

              </div>

          <?php 
            endwhile; 
            wp_reset_postdata(); 
            endif; 
          ?>
          
 </div><!--widgetBody-->

 <?php
 echo $after_widget;

}
/**
   * Saves widget settings.
   *
   * @since  1.0
   *
   * @access public
   * @param  array $new_instance
   * @param  array $old_instance
   * @return array
   */
public function update( $new_instance,$old_instance ){
    $instance  =  $old_instance;
    $instance['title'] = strip_tags( $new_instance['title'] );
    $instance['cats_id'] = implode( ',' , $new_instance['cats_id']  );
    $instance['nbr_posts'] = (int)$new_instance['nbr_posts'];
    $instance['offset'] = (int)$new_instance['offset'];
    $instance['background_color'] =  $new_instance['background_color'];

       return $instance;
}

public function form($inst){

    $title = isset( $inst['title'] ) ? esc_attr( $inst['title'] ) : '';
    $background_color = isset( $inst['background_color'] ) ? esc_attr( $inst['background_color'] ) : '#FFA500';
    $nbr_posts = isset( $inst['nbr_posts'] ) ? esc_attr( $inst['nbr_posts'] ) : '6';
    $offset = isset( $inst['offset'] ) ? esc_attr( $inst['offset'] ) : '0';
    $category = isset( $inst['cats_id'] ) ? esc_attr( $inst['cats_id'] ) : '';
    $cats_id = explode ( ',' , $category ) ;
    $categories_obj = get_categories();
    $categories = array();

  foreach ( $categories_obj as $pn_cat ) {
    $categories[$pn_cat->cat_ID] = $pn_cat->cat_name;
  }
  ?>

  <p>
    <label for="<?php echo $this->get_field_id( 'background_color' ); ?>"><?php _e( 'Border Color:', 'enamag' );?><br></label>
    <input class="widefat color-picker" type="text" id="<?php echo $this->get_field_id( 'background_color' ); ?>" name="<?php echo $this->get_field_name( 'background_color' ); ?>" value="<?php echo  $background_color ; ?>" />                            
  </p>
  <p>
    <label for="<?php  echo $this->get_field_id( "title" ) ;?>"><?php _e( 'Title:', 'enamag' ); ?></label>
    <input class="widefat" value="<?php echo $title;?>" name="<?php  echo $this->get_field_name( "title" ) ;?>" type="text" id="<?php  echo $this->get_field_id( "title" ) ;?>"/>
  </p>
  <p>
    
    <label for="<?php echo $this->get_field_id( 'cats_id' ); ?>"><?php _e( 'Select Category:', 'enamag' );?></label><br>
    <select class="widefat" multiple="multiple" id="<?php echo $this->get_field_id( 'cats_id' ); ?>[]" name="<?php echo $this->get_field_name( 'cats_id' ); ?>[]">
      
      <?php foreach ( $categories as $key => $option ) { ?>

      <option value="<?php echo $key ?>" <?php if ( in_array( $key , $cats_id ) ) { echo ' selected="selected"' ; } ?>><?php echo $option; ?></option>
      
      <?php  } ?>

    </select>
  </p>
  <p>
      <label for="<?php  echo $this->get_field_id( "offset" ) ;?>"><?php _e( 'Offset:', 'enamag' ); ?></label>
      <input  value="<?php echo $offset;?>" type="text" size="3" name="<?php  echo $this->get_field_name( "offset" ) ;?>" id="<?php  echo $this->get_field_id( "offset" ) ;?>" />
  </p>
  <p>
   <label for="<?php  echo $this->get_field_id( "nbr_posts" ) ;?>"><?php _e( 'Number of posts to show:', 'enamag' ); ?></label>
  <input  value="<?php echo $nbr_posts;?>" type="text" size="3" name="<?php  echo $this->get_field_name( "nbr_posts" ) ;?>" id="<?php  echo $this->get_field_id( "nbr_posts" ) ;?>" />
  </p>

 <?php

 }
}

add_action( 'widgets_init', 'ena_widget_warge' );
function ena_widget_warge() {
  register_widget( 'Ena_Widget_Large' );
}
